/* Sistemas Integrados TECNISA
   Planejamento Alimentao Industrial

Nome: CALCULA_PREVCONS_FILIAIS

Descrio:
Clculo da Previso de Consumo p/ filiais

P_CDFILIAL     - Lista de filiais
P_TCDFILIAL    - Todas as filiais
P_GRUPFILI     - Agrupamento de Filial
P_DTFINAL      - Data final de clculo
P_PEACRESCIMO  - Percentual de acrscimo
P_CDPRODUTOINI - Cdigo do produto inicial (CDARVPROD)
P_CDPRODUTOFIN - Cdigo do produto final   (CDARVPROD)
P_CDOPERADOR   - Cdigo do operador que solicitou o clculo
P_DTHRCALCPC   - Data/hora do clculo
P_STDTINICIAL  - Lista de data inicial (em string) por servio
P_STDTFINAL    - Lista de data final (em string) por servio
Para aplicar e debugar
 @C:\WIN_V4\SQL\END_CONV\SQLSERVER\7135_PLASTPS.SQL;

Criao:
17/12/2004 - Marcelo Alexsandro Souza Silva
*/

IF EXISTS (SELECT * FROM sysobjects O, sysusers U
          WHERE
            o.name = 'CALCULA_PREVCONS_FILIAIS'  and
            type = 'P'                  and
            u.uid = o.uid               and
            u.name = USER)
   DROP PROCEDURE CALCULA_PREVCONS_FILIAIS;
GO


CREATE PROCEDURE CALCULA_PREVCONS_FILIAIS
  (@P_CDFILIAL     VARCHAR(4),
   @P_TCDFILIAL    VARCHAR(1),
   @P_CDGRUPFILI   VARCHAR(10),
   @P_DTFINAL      DATETIME,
   @P_PEACRESCIMO  NUMERIC,
   @P_CDPRODUTOINI VARCHAR(20),
   @P_CDPRODUTOFIN VARCHAR(20),
   @P_CDOPERADOR   VARCHAR(12),
   @P_DTHRCALCPC   DATETIME,
   @P_IDARREDOND   VARCHAR(1),
   @P_STDTINICIAL  VARCHAR(2000) = NULL,
   @P_STDTFINAL    VARCHAR(2000) = NULL)
AS

DECLARE @V_DATAPROC  DATETIME;
DECLARE @V_IDUTILDTPROC VARCHAR(1);
DECLARE @V_PRXCONSPLAN VARCHAR(20);
DECLARE @V_CDPRODUTOFIN VARCHAR(50);
DECLARE @VCUR_FILIAL VARCHAR(4);
DECLARE @VCUR_CDSERVFILI VARCHAR(5)

BEGIN
   SET @V_IDUTILDTPROC = '';
   SELECT
      @V_IDUTILDTPROC = MAX(IDUTILDTPROC)
   FROM
      PARAMGERAL;

   DECLARE CUR_FILIAL CURSOR FOR
      (SELECT
          FILIAL.CDFILIAL
       FROM
          FILIAL
       WHERE
          (CHARINDEX(FILIAL.CDFILIAL, @P_CDFILIAL) > 0 OR @P_TCDFILIAL = 'T') AND
          (@P_CDGRUPFILI IS NULL)
       UNION ALL
       SELECT
          FILGRUPFILI.CDFILIAL
       FROM
          FILGRUPFILI
       WHERE
          (CHARINDEX(FILGRUPFILI.CDFILIAL, @P_CDFILIAL) > 0 OR @P_TCDFILIAL = 'T') AND
          (FILGRUPFILI.CDGRUPFILI = @P_CDGRUPFILI))
   OPEN CUR_FILIAL;
   FETCH NEXT FROM CUR_FILIAL INTO @VCUR_FILIAL;
   WHILE (@@FETCH_STATUS = 0)
   BEGIN
      SET @V_PRXCONSPLAN  = '';
      SET @V_CDPRODUTOFIN = '';
      SET @V_CDPRODUTOFIN = @P_CDPRODUTOFIN;

/* - Verifica a data de processamento para a filial informada ------------ */
      IF @V_IDUTILDTPROC <> 'S' BEGIN
         SET @V_DATAPROC = CONVERT(DATETIME,GETDATE(),103);
      END
      ELSE BEGIN
         SELECT
            @V_DATAPROC = MAX(ISNULL(DTPROCESSA, CONVERT(DATETIME,GETDATE(),103)))
         FROM
            PARAMFILIAL
         WHERE
            CDFILIAL = @VCUR_FILIAL;
      END;

      EXEC NOVO_CODIGO 'CONSPLAN', @P_SEQUENCIAL = @V_PRXCONSPLAN OUTPUT, @P_QTDE = 1;
      SET @V_PRXCONSPLAN = SUBSTRING(@V_PRXCONSPLAN,11,10);
      EXEC PREVISAO_DE_CONSUMO_PLA @VCUR_FILIAL,
                                   'T', /*P_CDSERVFILI :  Sempre sero todos os servios*/
                                   @V_DATAPROC,
                                   @P_DTFINAL,
                                   @P_PEACRESCIMO,
                                   @P_CDPRODUTOINI,
                                   @V_CDPRODUTOFIN,
                                   @P_CDOPERADOR,
                                   @P_DTHRCALCPC,
                                   @V_PRXCONSPLAN,
                                   @P_IDARREDOND,
                                   @P_STDTINICIAL,
                                   @P_STDTFINAL;
      FETCH NEXT FROM CUR_FILIAL INTO @VCUR_FILIAL;
   END;
   CLOSE CUR_FILIAL;
   DEALLOCATE CUR_FILIAL;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'CALCULA_PREVCONS_FILIAIS','5.01.001';
GO

